import java.io.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.SwingUtilities;
import javax.swing.filechooser.*;
import javax.swing.tree.*;

public class OdfSender extends JFrame implements ActionListener{

	private JFileChooser fc;
	private JButton openButton, sendButton, clearButton;
	private String selectedDirectory;
	private JComboBox fileList;
	private JTextArea log;
	private JScrollPane logPane;

	public OdfSender() {
        //Window setup
        super("ODF Sender");
        setSize(550, 320);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    }
	
	//Entrance into application
	public static void main(String[] args){
		OdfSender selector = new OdfSender();
		selector.init();
		selector.setVisible(true);
	}
	
	public void init(){
		//file chooser allows directories only
		fc = new JFileChooser();
		fc.setFileSelectionMode(JFileChooser.DIRECTORIES_ONLY);
		fileList = new JComboBox();
		Icon icon = UIManager.getIcon("FileView.directoryIcon"); //get java directory icon
		//create buttons
		openButton = new JButton(icon);
		sendButton = new JButton("Send");
		sendButton.setVisible(false);
		clearButton = new JButton("Clear Log");
		//add action listeners
		openButton.addActionListener(this);
		sendButton.addActionListener(this);
		clearButton.addActionListener(this);
		//create log
		fileList.addItem("Select a Directory...");
		log = new JTextArea("Sending log: \n",12,42);
		log.setEditable(false);
		logPane = new JScrollPane(log);
		
		//create panels for layout
		JPanel mainPanel = new JPanel();
		mainPanel.setLayout(new BorderLayout());
		JPanel inputPanel = new JPanel(); //use FlowLayout
		JPanel logPanel = new JPanel();
		
		//add elements to panels
		mainPanel.add(inputPanel, BorderLayout.NORTH);
		mainPanel.add(logPanel, BorderLayout.CENTER);
        inputPanel.add(fileList);
		inputPanel.add(openButton);
		inputPanel.add(sendButton);
		logPanel.add(logPane);
		mainPanel.add(clearButton, BorderLayout.SOUTH);
		
		//add main panel to frame
		getContentPane().add(mainPanel);
	}
	
	public void actionPerformed(ActionEvent e) {
         //Handle open button action
        if (e.getSource() == openButton) {
			
			int returnVal = fc.showOpenDialog(OdfSender.this);
            if (returnVal == JFileChooser.APPROVE_OPTION){
				//get the directory name
                File directory = fc.getSelectedFile();
				selectedDirectory = directory.getAbsolutePath();
				//clear the comboBox
				fileList.removeAllItems();
				
				//loop through directory and add each file to comboBox
				File[] listOfFiles = directory.listFiles(); 
				for (int i = 0; i < listOfFiles.length; i++){
					if (listOfFiles[i].isFile()){
						String s = new String(listOfFiles[i].getName());
						fileList.addItem(s);
					}
				}
				sendButton.setVisible(true);
			}				
		}
		//Handle send button action
		if (e.getSource() == sendButton) {
			DefaultTreeModel tree;
			//Get the filename
			int i = fileList.getSelectedIndex();
			String s = fileList.getItemAt(i).toString();
			//add file name to log
			log.append(s+" sent...\n");
			//Create a SAXTreeViewer to parse the XML file
			SAXTreeViewer viewer = new SAXTreeViewer();
			try{
				//create a tree from the XML file
				tree = viewer.init(selectedDirectory+ "\\" +s);
				JTree t = new JTree(tree);
				JFrame f = new JFrame();
				f.getContentPane().add(new JScrollPane(t), 
				BorderLayout.CENTER);
				f.setVisible(true);
				log.append("Success!\n");
				OdfProcessor p = new OdfProcessor();
				p.process(tree);
			}
			catch(Exception ex){
				ex.printStackTrace();
			}		
			
			//set the scroll pane to automatically scroll to the bottom
			JScrollBar vertical = logPane.getVerticalScrollBar();
			vertical.setValue( vertical.getMaximum() );
			
			//advance to next file in the list if not the last file
			if(fileList.getSelectedIndex() != (fileList.getItemCount()-1)){
				fileList.setSelectedIndex(i+1);
			}
			else{
				//if it is the last file
				log.append("END OF FILES\n");
			}
		}
		
		if (e.getSource() == clearButton) {
			//clear the log
			log.setText("Sending log:\n");
		}
	}
}